| df_to_table | R Documentation |
Convert a data frame to a contingency table
df_to_table(df, label_col = NULL)
df |
A data frame. Either (a) one column contains row labels and the rest are
numeric, (b) a fully numeric data frame with meaningful |
label_col |
Index or name of the column containing row labels. If NULL (default),
the function auto-detects the first character/factor column. If no such column is
found, the function falls back to using |
A contingency table.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.