- formula
A formula specifying the response and predictor variable (e.g., response ~ predictor).
more response variables and predictors can be added using - or + (e.g., response1 + response2 ~ predictor1 + predictor2). The function iterates through these combinations or response and predictors, because the Kruskal-Wallis test itself only allows one response and one predictor combination to be tested simultaneously.
- data
A data.frame containing the variables referenced in the formula.
- plot
Logical. If TRUE, generates plots (e.g., density plots and boxplots)
in the output files. Default is TRUE.
- alpha
Numeric. The significance level for the Kruskal-Wallis test and Dunn's
test. Default is 0.05.
- output_type
Character string specifying the output format: "pdf", "word", "excel", "rmd", "console" or "off" (no file generated). The option "console" forces output to be printed, the option "rmd" saves rmd code in the output object not in a file. Default is "off".
- save_as
Character string specifying the output file path (without extension).
If a full path is provided, output is saved to that location.
If only a filename is given, the file is saved in tempdir().
If only a directory is specified (providing an existing directory with trailing slash),
the file is named "dataname_Kruskal_Wallis_output" in that directory. If an extension is provided the output format specified with option "output_type" will be overruled.
Defaults to file.path(tempdir(), "dataname_summary.pdf").
- save_in_wdir
Logical. If TRUE, saves the file in the working directory. Default is FALSE, this avoid unintended changes to the global environment. If save_as location is specified save_in_wdir is overwritten by save_as.
- intro_text
Logical. If TRUE, includes a section about Kruskal-Wallis test assumptions in the output document. Default is TRUE.
- adjust
Character string. Adjustment method for pairwise comparisons in Dunn's test. Options include "holm", "hommel", "bonferroni", "sidak", "hs", "hochberg", "bh", "by", "fdr" or "none". Default is "bonferroni", if you don't want to adjust the p value (not recommended), use p.adjust.method = "none".
- close_generated_files
Logical. If TRUE, closes open 'Excel' or 'Word' files depending on the output format. This to be able to save the newly generated file by the f_aov() function. 'Pdf' files should also be closed before using the function and cannot be automatically closed. Default is FALSE.
- open_generated_files
Logical. If TRUE, Opens the generated output files ('pdf', 'Word' or 'Excel') files depending on the output format. This to directly view the results after creation. Files are stored in tempdir(). Default is TRUE.